@@ -12,12 +12,13 @@ async fn main() {
 
     dotenv().ok();
     let matches = Opt::into_app()
-        .version(crate_version!())
         .bin_name("cargo sqlx")
         .setting(AppSettings::NoBinaryName)
         .get_matches_from(args);
 
-    if let Err(error) = sqlx_cli::run(Opt::from_arg_matches(&matches)).await {
+    let opt = Opt::from_arg_matches(&matches).unwrap_or_else(|e| e.exit());
+
+    if let Err(error) = sqlx_cli::run(opt).await {
         println!("{} {}", style("error:").bold().red(), error);
         process::exit(1);
     }
