@@ -115,16 +115,16 @@ hint: This command only works in the manifest directory of a Cargo package."#
             bail!("`cargo clean` failed with status: {}", check_status);
         }
 
+        let mut rustflags = env::var("RUSTFLAGS").unwrap_or_default();
+        rustflags.push_str(&format!(
+            " --cfg __sqlx_recompile_trigger=\"{}\"",
+            SystemTime::UNIX_EPOCH.elapsed()?.as_millis()
+        ));
+
         Command::new(&cargo)
             .arg("check")
             .args(cargo_args)
-            .env(
-                "RUSTFLAGS",
-                format!(
-                    "--cfg __sqlx_recompile_trigger=\"{}\"",
-                    SystemTime::UNIX_EPOCH.elapsed()?.as_millis()
-                ),
-            )
+            .env("RUSTFLAGS", rustflags)
             .env("SQLX_OFFLINE", "false")
             .status()?
     } else {
